EDGAR Search Results
Mailing Address ONE APPLE PARK WAY CUPERTINO CA 95014
Business Address ONE APPLE PARK WAY CUPERTINO CA 95014 (408) 996-1010
Apple Inc. CIK#: 0000320193 (see all company filings)

SIC: 3571 - ELECTRONIC COMPUTERS
State location: CA | State of Inc.: CA | Fiscal Year End: 0926
formerly: APPLE COMPUTER INC (filings through 2007-01-04)
formerly: APPLE COMPUTER INC/ FA (filings through 1997-07-28)
formerly: APPLE INC (filings through 2019-08-05)
(Office of Technology)
Get insider transactions for this issuer.

Filter Results: | Filing Type: | Prior to: (YYYYMMDD) | Ownership? include exclude only | Limit Results Per Page |

Items 1 - 40 RSS Feed |

Filings | Format | Description | Filing Date | File/Film Number
--- | --- | --- | --- | ---
10-Q | Documents Interactive Data | Quarterly report [Sections 13 or 15(d)] Acc-no: 0000320193-20-000010 (34 Act) Size: 9 MB | 2020-01-29 | 001-36743 20555794
8-K | Documents Interactive Data | Current report, items 2.02 and 9.01 Acc-no: 0000320193-20-000008 (34 Act) Size: 531 KB | 2020-01-28 | 001-36743 20554729
PX14A6G | Documents | Notice of exempt solicitation submitted by non-management Acc-no: 0001214659-20-000610 (34 Act) Size: 87 KB | 2020-01-27 | 001-36743 20548807
PX14A6G | Documents | Notice of exempt solicitation submitted by non-management Acc-no: 0001387131-20-000386 (34 Act) Size: 45 KB | 2020-01-22 | 001-36743 20537776
DEFA14A | Documents | Additional definitive proxy soliciting materials and Rule 14(a)(12) material Acc-no: 0001193125-20-001452 (34 Act) Size: 715 KB | 2020-01-03 | 001-36743 20506033
DEF 14A | Documents | Other definitive proxy statements Acc-no: 0001193125-20-001450 (34 Act) Size: 4 MB | 2020-01-03 | 001-36743 20505940
CERT | Documents | Acc-no: 0001354457-19-000604 (34 Act) Size: 202 KB | 2019-11-15 | 001-36743 191222519
8-A12B | Documents | Registration of securities [Section 12(b)] Acc-no: 0001193125-19-292825 (34 Act) Size: 19 KB | 2019-11-15 | 001-36743 191222426
8-K | Documents Interactive Data | Current report, items 8.01 and 9.01 Acc-no: 0001193125-19-292676 (34 Act) Size: 645 KB | 2019-11-15 | 001-36743 191222355
424B2 | Documents | Prospectus [Rule 424(b)(2)] Acc-no: 0001193125-19-288412 (33 Act) Size: 439 KB | 2019-11-08 | 333-228159 191204489
FWP | Documents | Filing under Securities Act Rules 163/433 of free writing prospectuses Acc-no: 0001193125-19-287351 (34 Act) Size: 35 KB | 2019-11-07 | 333-228159 191200817
424B2 | Documents | Prospectus [Rule 424(b)(2)] Acc-no: 0001193125-19-286514 (33 Act) Size: 433 KB | 2019-11-07 | 333-228159 191197982
S-8 POS | Documents | Securities to be offered to employees in employee benefit plans, post-effective amendments Acc-no: 0001193125-19-280516 (33 Act) Size: 74 KB | 2019-10-31 | 333-165214 191184102
10-K | Documents Interactive Data | Annual report [Section 13 and 15(d), not S-K Item 405] Acc-no: 0000320193-19-000119 (34 Act) Size: 12 MB | 2019-10-31 | 001-36743 191181423
8-K | Documents Interactive Data | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000117 (34 Act) Size: 576 KB | 2019-10-30 | 001-36743 191180631
8-K | Documents Interactive Data | Current report, item 5.02 Acc-no: 0000320193-19-000093 (34 Act) Size: 295 KB | 2019-09-13 | 001-36743 191093220
8-K | Documents Interactive Data | Current report, items 8.01 and 9.01 Acc-no: 0001193125-19-242975 (34 Act) Size: 777 KB | 2019-09-11 | 001-36743 191088535
424B2 | Documents | Prospectus [Rule 424(b)(2)] Acc-no: 0001193125-19-238922 (33 Act) Size: 390 KB | 2019-09-05 | 333-228159 191077641
FWP | Documents | Filing under Securities Act Rules 163/433 of free writing prospectuses Acc-no: 0001193125-19-237993 (34 Act) Size: 82 KB | 2019-09-05 | 333-228159 191075999
424B2 | Documents | Prospectus [Rule 424(b)(2)] Acc-no: 0001193125-19-237090 (33 Act) Size: 375 KB | 2019-09-04 | 333-228159 191073320
10-Q | Documents Interactive Data | Quarterly report [Sections 13 or 15(d)] Acc-no: 0000320193-19-000076 (34 Act) Size: 10 MB | 2019-07-31 | 001-36743 19989192
8-K | Documents | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000073 (34 Act) Size: 303 KB | 2019-07-30 | 001-36743 19985848
10-Q | Documents Interactive Data | Quarterly report [Sections 13 or 15(d)] Acc-no: 0000320193-19-000066 (34 Act) Size: 10 MB | 2019-05-01 | 001-36743 19788072
8-K | Documents | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000063 (34 Act) Size: 289 KB | 2019-04-30 | 001-36743 19782221
CERT | Documents | Acc-no: 0001354457-19-000130 (34 Act) Size: 154 KB | 2019-03-14 | 001-36743 19681650
25 | Documents | Notification of the removal from listing and registration of matured, redeemed or retired securities Acc-no: 0001193125-19-074874 (34 Act) Size: 13 KB | 2019-03-14 | 001-36743 19681578
8-A12B | Documents | Registration of securities [Section 12(b)] Acc-no: 0001193125-19-074868 (34 Act) Size: 22 KB | 2019-03-14 | 001-36743 19681549
8-K | Documents | Current report, item 5.07 Acc-no: 0000320193-19-000032 (34 Act) Size: 66 KB | 2019-03-04 | 001-36743 19654221
SD | Documents | Acc-no: 0001193125-19-041571 (34 Act) Size: 585 KB | 2019-02-15 | 001-36743 19609779
SC 13G | Documents | Statement of acquisition of beneficial ownership by individuals Acc-no: 0001193125-19-041014 (34 Act) Size: 702 KB | 2019-02-14 | 005-33632 19607502
SC 13G/A | Documents | [Amend] Statement of acquisition of beneficial ownership by individuals Acc-no: 0000932471-19-004418 (34 Act) Size: 34 KB | 2019-02-11 | 005-33632 19582280
8-K | Documents | Current report, item 5.02 Acc-no: 0000320193-19-000026 (34 Act) Size: 29 KB | 2019-02-06 | 001-36743 19569878
PX14A6G | Documents | Notice of exempt solicitation submitted by non-management Acc-no: 0001214659-19-000797 (34 Act) Size: 10 KB | 2019-02-05 | 001-36743 19566496
SC 13G/A | Documents | [Amend] Statement of acquisition of beneficial ownership by individuals Acc-no: 0000215457-19-003343 (34 Act) Size: 13 KB | 2019-02-04 | 005-33632 19562213
10-Q | Documents Interactive Data | Quarterly report [Sections 13 or 15(d)] Acc-no: 0000320193-19-000010 (34 Act) Size: 8 MB | 2019-01-30 | 001-36743 19552275
8-K | Documents | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000007 (34 Act) Size: 228 KB | 2019-01-29 | 001-36743 19549017
DEFA14A | Documents | Additional definitive proxy soliciting materials and Rule 14(a)(12) material Acc-no: 0001193125-19-004678 (34 Act) Size: 470 KB | 2019-01-08 | 001-36743 19516394
DEF 14A | Documents | Other definitive proxy statements Acc-no: 0001193125-19-004664 (34 Act) Size: 5 MB | 2019-01-08 | 001-36743 19516351
8-K | Documents | Current report, items 2.02 and 9.01 Acc-no: 0000320193-19-000002 (34 Act) Size: 66 KB | 2019-01-02 | 001-36743 19502044
S-3ASR | Documents | Automatic shelf registration statement of securities of well-known seasoned issuers Acc-no: 0001193125-18-317844 (33 Act) Size: 768 KB | 2018-11-05 | 333-228159 181158810